# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.service_update_app_installer_request import ServiceUpdateAppInstallerRequest

class TestServiceUpdateAppInstallerRequest(unittest.TestCase):
    """ServiceUpdateAppInstallerRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServiceUpdateAppInstallerRequest:
        """Test ServiceUpdateAppInstallerRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServiceUpdateAppInstallerRequest`
        """
        model = ServiceUpdateAppInstallerRequest()
        if include_optional:
            return ServiceUpdateAppInstallerRequest(
                description = '',
                links = nuon.models.service_update_app_installer_request_links.service_UpdateAppInstallerRequest_links(
                    community = '', 
                    demo = '', 
                    documentation = '', 
                    github = '', 
                    homepage = '', 
                    logo = '', ),
                name = ''
            )
        else:
            return ServiceUpdateAppInstallerRequest(
                description = '',
                name = '',
        )
        """

    def testServiceUpdateAppInstallerRequest(self):
        """Test ServiceUpdateAppInstallerRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
