# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.statsd_event_alert_type import StatsdEventAlertType

class TestStatsdEventAlertType(unittest.TestCase):
    """StatsdEventAlertType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStatsdEventAlertType(self):
        """Test StatsdEventAlertType"""
        # inst = StatsdEventAlertType()

if __name__ == '__main__':
    unittest.main()
